diff --git a/.gitignore b/.gitignore
index 96fe426..32ad3e1 100644
--- a/.gitignore
+++ b/.gitignore
@@ -28,3 +28,4 @@ deploy/
# Config files
chirp.conf
+telephant.conf
diff --git a/README.md b/README.md
index 9074348..3d37bbb 100644
--- a/README.md
+++ b/README.md
@@ -1,9 +1,9 @@
-Chirp!
+Telephant!
======
A lightweight but modern Social Media client, written in Go & QML.
-![chirp Screenshot](/assets/screenshot.png)
+![telephant Screenshot](/assets/screenshot.png)
## Features
@@ -24,27 +24,21 @@ See the [install instructions](http://golang.org/doc/install.html).
### Dependencies
-Before you can build Chirp you need to install the [Go/Qt bindings](https://github.com/therecipe/qt/wiki/Installation#regular-installation).
+Before you can build Telephant you need to install the [Go/Qt bindings](https://github.com/therecipe/qt/wiki/Installation#regular-installation).
-### Building Chirp!
+### Building Telephant!
- git clone https://github.com/muesli/chirp.git
- qtdeploy build desktop chirp/
+ git clone https://github.com/muesli/telephant.git
+ qtdeploy build desktop telephant/
### Run it
- ./chirp/deploy/linux/chirp
+ ./telephant/deploy/linux/telephant
-### Config
-
-As of now you will need to create your own API apps & keys to use Chirp. You can do this on [https://dev.twitter.com/](https://dev.twitter.com/).
-When you run Chirp for the first time, it will create an empty config file `chirp.conf` for you. Just edit it and enter
-your consumer key and accesstoken.
-
-![chirp logo](/assets/chirp.png)
+![telephant logo](/assets/telephant.png)
## Development
-[![GoDoc](https://godoc.org/github.com/golang/gddo?status.svg)](https://godoc.org/github.com/muesli/chirp)
-[![Build Status](https://travis-ci.org/muesli/chirp.svg?branch=master)](https://travis-ci.org/muesli/chirp)
-[![Go ReportCard](http://goreportcard.com/badge/muesli/chirp)](http://goreportcard.com/report/muesli/chirp)
+[![GoDoc](https://godoc.org/github.com/golang/gddo?status.svg)](https://godoc.org/github.com/muesli/telephant)
+[![Build Status](https://travis-ci.org/muesli/telephant.svg?branch=master)](https://travis-ci.org/muesli/telephant)
+[![Go ReportCard](http://goreportcard.com/badge/muesli/telephant)](http://goreportcard.com/report/muesli/telephant)
diff --git a/accounts/events.go b/accounts/events.go
index be3d42e..ff574b0 100644
--- a/accounts/events.go
+++ b/accounts/events.go
@@ -1,4 +1,4 @@
-// Package accounts is chirp's account "plugin" system.
+// Package accounts is telephant's account "plugin" system.
package accounts
import "time"
diff --git a/assets/chirp.png b/assets/telephant.png
similarity index 100%
rename from assets/chirp.png
rename to assets/telephant.png
diff --git a/bridges.go b/bridges.go
index 702e564..6ad4309 100644
--- a/bridges.go
+++ b/bridges.go
@@ -1,7 +1,7 @@
package main
import (
- "github.com/muesli/chirp/accounts/mastodon"
+ "github.com/muesli/telephant/accounts/mastodon"
"github.com/therecipe/qt/core"
)
@@ -84,7 +84,7 @@ func setupQmlBridges() {
configBridge = NewConfigBridge(nil)
accountBridge = NewAccountBridge(nil)
- accountBridge.SetUsername("Chirp!")
+ accountBridge.SetUsername("Telephant!")
uiBridge = NewUIBridge(nil)
uiBridge.ConnectConnectButton(connectToInstance)
diff --git a/events.go b/events.go
index e669939..5ae99cb 100644
--- a/events.go
+++ b/events.go
@@ -5,7 +5,7 @@ import (
"log"
"strings"
- "github.com/muesli/chirp/accounts"
+ "github.com/muesli/telephant/accounts"
)
func linkify(in []byte) []byte {
diff --git a/qml/AboutDialog.qml b/qml/AboutDialog.qml
index 7261e3c..9c42aca 100644
--- a/qml/AboutDialog.qml
+++ b/qml/AboutDialog.qml
@@ -20,7 +20,7 @@ import QtQuick.Layouts 1.3
Label {
width: aboutDialog.availableWidth
- text: "Chirp! by @mueslix"
+ text: "Telephant! by @mueslix"
textFormat: Text.RichText
wrapMode: Label.Wrap
font.pixelSize: 12
@@ -35,7 +35,7 @@ import QtQuick.Layouts 1.3
Label {
width: aboutDialog.availableWidth
- text: qsTr("Chirp! is a light-weight but modern Twitter client")
+ text: qsTr("Telephant! is a light-weight but modern social media client")
textFormat: Text.RichText
wrapMode: Label.Wrap
font.pixelSize: 12
diff --git a/qml/chirp.qml b/qml/telephant.qml
similarity index 100%
rename from qml/chirp.qml
rename to qml/telephant.qml
diff --git a/chirp.go b/telephant.go
similarity index 97%
rename from chirp.go
rename to telephant.go
index 1daac12..719b385 100644
--- a/chirp.go
+++ b/telephant.go
@@ -10,7 +10,7 @@ import (
"github.com/therecipe/qt/qml"
"github.com/therecipe/qt/quickcontrols2"
- "github.com/muesli/chirp/accounts/mastodon"
+ "github.com/muesli/telephant/accounts/mastodon"
)
var (
@@ -168,7 +168,7 @@ func runApp(config Config) {
app.RootContext().SetContextProperty("profileBridge", profileBridge)
app.RootContext().SetContextProperty("settings", configBridge)
- app.Load(core.NewQUrl3("qrc:/qml/chirp.qml", 0))
+ app.Load(core.NewQUrl3("qrc:/qml/telephant.qml", 0))
gui.QGuiApplication_Exec()
}
@@ -195,7 +195,7 @@ func setupMastodon(config Account) {
}
func main() {
- core.QCoreApplication_SetApplicationName("Chirp")
+ core.QCoreApplication_SetApplicationName("Telephant")
core.QCoreApplication_SetOrganizationName("fribbledom.com")
core.QCoreApplication_SetAttribute(core.Qt__AA_EnableHighDpiScaling, true)
gui.NewQGuiApplication(len(os.Args), os.Args)
diff --git a/accounts/mastodon/mastodon.go b/accounts/mastodon/mastodon.go
index 7bceab7..d874183 100644
--- a/accounts/mastodon/mastodon.go
+++ b/accounts/mastodon/mastodon.go
@@ -1,4 +1,4 @@
// Package mastodon is a Mastodon account for Chirp.
package mastodon
import (
@@ -12,7 +12,7 @@ import (
"github.com/davecgh/go-spew/spew"
"github.com/mattn/go-mastodon"
- "github.com/muesli/chirp/accounts"
+ "github.com/muesli/telephant/accounts"
)
const (
@@ -20,7 +20,7 @@ const (
initialNotificationsCount = 40
)
// Account is a Mastodon account for Chirp.
type Account struct {
client *mastodon.Client
config *mastodon.Config
@@ -1,4 +1,4 @@
-// Package mastodon is a Mastodon account for Chirp.
+// Package mastodon is a Mastodon account for Telephant.
package mastodon
import (
@@ -20,7 +20,7 @@ const (
initialNotificationsCount = 40
)
-// Account is a Mastodon account for Chirp.
+// Account is a Mastodon account for Telephant.
type Account struct {
client *mastodon.Client
diff --git a/accounts/twitter/twitter.go b/accounts/twitter/twitter.go
index ff81597..39b7277 100644
--- a/accounts/twitter/twitter.go
+++ b/accounts/twitter/twitter.go
@@ -1,4 +1,4 @@
// Package twitter is a Twitter account for Chirp.
package twitter
import (
@@ -11,7 +11,7 @@ import (
"github.com/ChimeraCoder/anaconda"
- "github.com/muesli/chirp/accounts"
+ "github.com/muesli/telephant/accounts"
)
const (
@@ -19,7 +19,7 @@ const (
initialNotificationsCount = 50
)
// Account is a twitter account for Chirp.
type Account struct {
consumerKey string
consumerSecret string
@@ -1,4 +1,4 @@
-// Package twitter is a Twitter account for Chirp.
+// Package twitter is a Twitter account for Telephant.
package twitter
import (
@@ -19,7 +19,7 @@ const (
initialNotificationsCount = 50
)
-// Account is a twitter account for Chirp.
+// Account is a twitter account for Telephant.
type Account struct {
consumerKey string
diff --git a/config.go b/config.go
index e112b41..2ecd627 100644
--- a/config.go
+++ b/config.go
@@ -22,14 +22,14 @@ type Account struct {
RedirectURI string
}
// Config holds chirp's config settings
type Config struct {
Account []Account
Style string
}
const (
- configFile = "chirp.conf"
+ configFile = "telephant.conf"
)
// LoadConfig returns the current config as a Config struct
@@ -22,14 +22,14 @@ type Account struct {
RedirectURI string
}
-// Config holds chirp's config settings
+// Config holds telephant's config settings
type Config struct {
Account []Account